@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 # coding: utf-8
-# Only pyfontaine developers should use this file to update files
-import logging
+# Only pyfontain developers should use this file to update files
 import os
 import os.path as op
 import requests
@@ -24,12 +23,7 @@ def get_data_directory():
 
 
 def get_file(name, url):
-    try:
-        r = requests.get(url)
-    except requests.exceptions.RequestException:
-        logging.warn(('Please run pyfontaine with an active internet '
-                      'connection to download all character maps'))
-        return False
+    r = requests.get(url)
     if r.status_code == 200:
         with open(name, 'w') as f:
             f.write(r.content)
