@@ -8,6 +8,7 @@
 #
 # Released under the GNU General Public License version 3 or later.
 # See accompanying LICENSE.txt file for details.
+import os
 
 from fontaine.cmap import library
 from fontaine.const import *
@@ -37,7 +38,7 @@ def lookup_languages(unichar):
     return charmaps
 
 
-class FontFace:
+class FontFace(object):
 
     def __init__(self, fontfile):
         import fontTools.ttLib as ttLib
@@ -94,46 +95,49 @@ class FontFace:
         return bool(self.ttf['head'].flags & FT_FACE_FLAG_FIXED_SIZES)
 
 
-class Font:
+class TTXFontFace(FontFace):
 
-    def __init__(self, fontfile, charmaps=[]):
+    def __init__(self, fontfile):
+        import fontTools.ttLib as ttLib
+        self.ttf = ttLib.TTFont(None)
+        self.ttf.importXML(fontfile, quiet=True)
+        self._flags = 0
 
+
+class FontFactory:
+
+    @staticmethod
+    def openfont(fontfile, charmaps=[]):
+        if fontfile.lower().endswith('.ttx'):
+            return TTXFont(fontfile, charmaps)
+        if fontfile.lower().endswith('.ufo') and os.path.isdir(fontfile):
+            try:
+                import robofab
+                return RoboFabFont(fontfile, charmaps)
+            except ImportError:
+                raise Exception('Install [RoboFab](https://pypi.python.org/pypi/robofab/) before using UFO with Pyfontaine')
         try:
             import freetype
-            self._fontFace = freetype.Face(fontfile)
-
-            self._unicodeValues = []
-            charcode, agindex = self._fontFace.get_first_char()
-            while agindex != 0:
-                self._unicodeValues.append(charcode)
-                charcode, agindex = self._fontFace.get_next_char(charcode, agindex)
-
+            return FreeTypeFont(fontfile, charmaps)
         except ImportError:
-            self._fontFace = FontFace(fontfile)
-            self._unicodeValues = self._fontFace.getCharmap()
+            pass
+        return TTFont(fontfile, charmaps)
+
+
+class TTFont(object):
+
+    def __init__(self, fontfile, charmaps=[]):
+        self._fontFace = FontFace(fontfile)
+        self._unicodeValues = self._fontFace.getCharmap()
 
         self._charmaps = map(str.lower, charmaps)
         self.refresh_sfnt_properties()
 
     def refresh_sfnt_properties(self):
-        try:
-            import freetype
-            sfnt_count = self._fontFace.sfnt_name_count
-            if not isinstance(sfnt_count, int):
-                return
-            for i in xrange(sfnt_count):
-                try:
-                    sfnt_record = self._fontFace.get_sfnt_name(i)
-                except freetype.FT_Exception:
-                    continue
-                propname = NAME_ID_FONTPROPMAP.get(sfnt_record.name_id)
-                value = unifyunicode(sfnt_record.string)
-                setattr(self, '_%s' % propname, value)
-        except ImportError:
-            for record in self._fontFace.getNames():
-                propname = NAME_ID_FONTPROPMAP.get(record.nameID)
-                value = unifyunicode(record.string)
-                setattr(self, '_%s' % propname, value)
+        for record in self._fontFace.getNames():
+            propname = NAME_ID_FONTPROPMAP.get(record.nameID)
+            value = unifyunicode(record.string)
+            setattr(self, '_%s' % propname, value)
 
     def get_othography_info(self, charmap, hits=0):
         ''' Return 4-tuple list with short orthographies information
@@ -279,3 +283,117 @@ class Font:
     @property
     def has_fixed_sizes(self):
         return self._fontFace.has_fixed_sizes
+
+
+class TTXFont(TTFont):
+
+    def __init__(self, fontfile, charmaps=[]):
+        self._fontFace = TTXFontFace(fontfile)
+        self._unicodeValues = self._fontFace.getCharmap()
+
+        self._charmaps = map(str.lower, charmaps)
+        self.refresh_sfnt_properties()
+
+
+class FreeTypeFont(TTFont):
+
+    def __init__(self, fontfile, charmaps=[]):
+        import freetype
+        self._unicodeValues = []
+        self._fontFace = freetype.Face(fontfile)
+        charcode, agindex = self._fontFace.get_first_char()
+        while agindex != 0:
+            self._unicodeValues.append(charcode)
+            charcode, agindex = self._fontFace.get_next_char(charcode, agindex)
+        self._charmaps = map(str.lower, charmaps)
+        self.refresh_sfnt_properties()
+
+    def refresh_sfnt_properties(self):
+        import freetype
+        sfnt_count = self._fontFace.sfnt_name_count
+        if not isinstance(sfnt_count, int):
+            return
+        for i in xrange(sfnt_count):
+            try:
+                sfnt_record = self._fontFace.get_sfnt_name(i)
+            except freetype.FT_Exception:
+                continue
+            propname = NAME_ID_FONTPROPMAP.get(sfnt_record.name_id)
+            value = unifyunicode(sfnt_record.string)
+            setattr(self, '_%s' % propname, value)
+
+
+class RoboFabFont(TTFont):
+
+    def __init__(self, fontfile, charmaps=[]):
+        import robofab.world
+        self._fontFace = robofab.world.OpenFont(fontfile)
+        self.info = self._fontFace.info.__dict__
+        self._unicodeValues = map(lambda x: x.unicode, self._fontFace)
+        self._charmaps = map(str.lower, charmaps)
+
+    @property
+    def common_name(self):
+        return self.info.get('familyName', '')
+
+    @property
+    def copyright(self):
+        return self.info.get('copyright', '')
+
+    @property
+    def designer(self):
+        return self.info.get('openTypeNameDesigner', '')
+
+    @property
+    def designer_url(self):
+        return self.info.get('openTypeNameManufacturerURL', '')
+
+    @property
+    def license(self):
+        return self.info.get('openTypeNameLicense', '')
+
+    @property
+    def license_url(self):
+        return self.info.get('openTypeNameLicenseURL', '')
+
+    @property
+    def glyph_num(self):
+        return len(self._unicodeValues)
+
+    @property
+    def style_flags(self):
+        return FT_STYLE_ITALIC \
+            if self.info.get('italicAngle') else ''
+
+    @property
+    def sub_family(self):
+        return self.info.get('styleName', '')
+
+    @property
+    def vendor(self):
+        return self._vendor
+    _vendor = ''
+
+    @property
+    def vendor_url(self):
+        return self._vendor_url
+    _vendor_url = ''
+
+    @property
+    def version(self):
+        return self.info.get('openTypeNameVersion', '')
+
+    @property
+    def weight(self):
+        return FT_STYLE_BOLD \
+            if self.info.get('openTypeOS2WeightClass', 0) >= 600 \
+            else FT_STYLE_NORMAL
+
+    @property
+    def is_fixed_width(self):
+        return bool(self.info.get('postscriptIsFixedPitch'))
+
+    @property
+    def has_fixed_sizes(self):
+        # always False
+        return False
